#' @name MorettinA7
#' @title Temperatura e Umidade do Ar na Cidade de São Paulo
#' @description Dados atmosféricos sobre temperatura
#'     (\code{Temperatura}) e umidade relativa do ar (\code{Umidade}),
#'     mensuradas ao meio-dia, na cidade de São Paulo. Observações
#'     diárias referentes a 1º de janeiro a 31 de jezembro de 1997.
#' @format Uma série temporal bivariada (classe \code{mts}), com 365
#'     observações diárias de 1º de janeiro a 31 de dezembro de 1997,
#'     das seguintes medidas:
#'
#' \describe{
#'
#' \item{\code{Temperatura}}{Temperaturas, mensuradas ao meio-dia em
#'     graus Celsius.}
#'
#' \item{\code{Umidade}}{Umidades relativa do ar, mensuradas ao meio-dia
#'     e expressas em porcentagem.}
#'
#' }
#' @seealso \code{\link{MorettinA6}}.
#' @keywords TS MTS
#' @source MORETTIN, TOLOI (2006), Série A7 - Atmosfera, descrita no
#'     Capítulo 1 pág. 17 e mencionada em diversas páginas).
#' @examples
#'
#' data(MorettinA7)
#' str(MorettinA7)
#' MorettinA7
#'
#' # Estatísticas resumo das séries
#' apply(MorettinA7, 2, summary)
#'
#' # Visualização da série
#' library(lattice)
#' xyplot(MorettinA7, type = c("o", "g"), pch = 19, col = "turquoise")
#'
#' # Mesclando com as séries dos agentes poluentes no mesmo período
#' # help(MorettinA6)
#' series <- ts.union(MorettinA6, MorettinA7)
#' xyplot(series, type = c("o", "g"), pch = 20, col = "black")
#'
NULL
