#' @name MorettinA8
#' @title Índices de Produtividade do Brasil
#' @description Séries temporais dos índices de produtividade (a) PIB -
#'     Produto Interno Bruto; (b) IPI - Produção Física Industrial -
#'     Produtos Alimentares; (c) PFI - Produção Física Industrial -
#'     Indústria Geral; e (d) Produção Física Industrial - Alimentação e
#'     Bebidas elaboradas para a indústria.
#' @format Uma lista de quatro elementos, em que
#'
#' \describe{
#'
#' \item{\code{A-PIB}}{São os valores do PIB - Produto Interno Bruto com
#'     observações anuais de 1861 a 1986.}
#'
#' \item{\code{M-IPI}}{Produção Física Industrial - Produtos Alimentares
#'     (base média de 1991=100), observações mensais de janeiro de 1985
#'     a a julho de 2000.}
#'
#' \item{\code{M-PFI}}{São os valores da Produção Física Industrial -
#'     Indústria geral (base média de 1991=100) com observações mensais
#'     de janeiro de 1985 a julho de 2000.}
#'
#' \item{\code{M-BEBIDA}}{São os valores da Produção Física Industrial
#'     - Alimentação e Bebidas elaboradas para Indústria (base média de
#'     1991=100) com observações mensais de janeiro de 1985 a julho de
#'     2000.}
#'
#' }
#'
#' @keywords TS MTS
#' @source MORETTIN, TOLOI (2006), Série A8 - Índices, descrita no
#'     Capítulo 1 pág. 17 e mencionada em diversas páginas.
#' @examples
#'
#' data(MorettinA8)
#' str(MorettinA8)
#'
#' # Estatísticas pontuais das séries
#' sapply(MorettinA8, summary)
#'
#' # Selecionando as séries individuais
#' (PIB <- MorettinA8[["A-PIB"]])
#' (PFI <- MorettinA8[["M-PFI"]])
#'
#' # Visualização das séries
#' library(lattice)
#'
#' xyplot(MorettinA8[["A-PIB"]], type = c("o", "g"), pch = 20)
#' xyplot(MorettinA8[["M-BEBIDA"]], type = c("o", "g"), pch = 20)
#'
#' # Juntando e visualizando as séries de mesma periodicidade
#' series <- do.call(ts.union,
#'                   MorettinA8[c("M-IPI", "M-PFI", "M-BEBIDA")])
#' xyplot(series, type = c("o", "g"), pch = 20, superpose = TRUE)
#'
NULL
